THIS SOFTAWRE CAN CALCULATE MULTIPLICATION, DIVISION, ADDITION, SUBTRACTION, MODULUS, EXPONENT AND FLOOR DIVISION.
HOW TO USE:
YOU MUST ENTER YOUR VALUES ACCORDDING TO THE PROMPT GIVEN.
INCASE OF AN OPERATOR PROMPT:
  ADDITION = +
  SUBTRACTION = -
  MULTIPLICATION = X OR x
  DIVISION = /
  MODULUS = %
  FLOOR DIVISION = //
  EXPONENT = *
WHEN ASKED TO QUIT YOU CAN EITHER PUT 'YES' WHICH WILL QUIT OR 'NO'.YOU WILL THEN BE PRESENTED WITH A CHOICE TO REST THE CALCULATOR OR NOT, IF YOU ENTER 'YES' YOU CAN START FROM THE BEGINNING ENTERING YOUR NUMBERS AND OPERATORS. IF YOU ENTER 'NO' YOU WILL BE PROMPTED TO ENTER THE SECOND NUMBER AND OPERATOR, DEPENDING ON THE OPERATOR, THE FIRST NUMBER WILL BE REPLACED WITH THE ANSWER OF THE PREVIOUS CALCULATION.
UNLESS YOU QUIT, THIS PROGRAM WILL WORK FOR AS MANY TIMES AS YOU WANT.

NEW FEATURES:

GUI MATH CALCULATOR INCLUDED
ENTER 'GUI' TO ACCESS GRAPHICAL USER INTERFACE MATH CALCULATOR
ENTER 'TUI' TO ACCESS TEXT BASED MATH CALCULATOR
PROGRAM WILL DEFAULT TO TEXT BASED MATH CALCULATOR IN THE CASE OF ANY ERROR